summaryrefslogtreecommitdiffstats
path: root/kwin/useractions.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
commitfd3a982e26813f5bcc82c7e89ce6fa2ad44432bf (patch)
tree9eda848e56fcb862fdfdf479adeccd95b6fe387a /kwin/useractions.cpp
parent02f67d0e1355b79b1806746efb0f2f640e57f13d (diff)
downloadtdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.tar.gz
tdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1212480 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kwin/useractions.cpp')
-rw-r--r--kwin/useractions.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kwin/useractions.cpp b/kwin/useractions.cpp
index 6ad2bf041..e825ac846 100644
--- a/kwin/useractions.cpp
+++ b/kwin/useractions.cpp
@@ -11,7 +11,7 @@ License. See the file "COPYING" for the exact licensing terms.
/*
- This file tqcontains things relevant to direct user actions, such as
+ This file contains things relevant to direct user actions, such as
responses to global keyboard shortcuts, or selecting actions
from the window operations menu.
@@ -229,7 +229,7 @@ void Workspace::desktopPopupAboutToShow()
id = desk_popup->insertItem(
basic_name
.arg(i)
- .arg( desktopName(i).tqreplace( '&', "&&" )),
+ .arg( desktopName(i).replace( '&', "&&" )),
i );
if ( active_popup_client &&
!active_popup_client->isOnAllDesktops() && active_popup_client->desktop() == i )
@@ -293,7 +293,7 @@ void Workspace::setupWindowShortcut( Client* c )
client_keys_client = c;
connect( client_keys_dialog, TQT_SIGNAL( dialogDone( bool )), TQT_SLOT( setupWindowShortcutDone( bool )));
TQRect r = clientArea( ScreenArea, c );
- TQSize size = client_keys_dialog->tqsizeHint();
+ TQSize size = client_keys_dialog->sizeHint();
TQPoint pos = c->pos() + c->clientPos();
if( pos.x() + size.width() >= r.right())
pos.setX( r.right() - size.width());
@@ -364,9 +364,9 @@ void Workspace::performWindowOperation( Client* c, Options::WindowOperation op )
return;
if (op == Options::MoveOp || op == Options::UnrestrictedMoveOp )
- TQCursor::setPos( c->tqgeometry().center() );
+ TQCursor::setPos( c->geometry().center() );
if (op == Options::ResizeOp || op == Options::UnrestrictedResizeOp )
- TQCursor::setPos( c->tqgeometry().bottomRight());
+ TQCursor::setPos( c->geometry().bottomRight());
switch ( op )
{
case Options::MoveOp:
@@ -1044,8 +1044,8 @@ void Workspace::showWindowMenu( const TQRect &pos, Client* cl )
else
{
TQRect area = clientArea(ScreenArea, TQPoint(x, y), currentDesktop());
- clientPopupAboutToShow(); // needed for tqsizeHint() to be correct :-/
- int popupHeight = p->tqsizeHint().height();
+ clientPopupAboutToShow(); // needed for sizeHint() to be correct :-/
+ int popupHeight = p->sizeHint().height();
if (y + popupHeight < area.height())
p->exec( TQPoint( x, y ) );
else
@@ -1093,7 +1093,7 @@ void Client::setShortcut( const TQString& _cut )
// Format:
// base+(abcdef)<space>base+(abcdef)
// E.g. Alt+Ctrl+(ABCDEF) Win+X,Win+(ABCDEF)
- if( !cut.tqcontains( '(' ) && !cut.tqcontains( ')' ) && !cut.tqcontains( ' ' ))
+ if( !cut.contains( '(' ) && !cut.contains( ')' ) && !cut.contains( ' ' ))
{
if( workspace()->shortcutAvailable( KShortcut( cut ), this ))
setShortcutInternal( KShortcut( cut ));